# PySAGAS Sensitivity Calculators


```{eval-rst}
.. automodule:: pysagas.sensitivity.calculator
   :members:
   :private-members:
```


## Supported CFD Wrappers
The following CFD sensitivity wrappers have been implemented into *PySAGAS*.

```{toctree}
:maxdepth: 2

cart3d
```